@@ -80,11 +80,6 @@ module GI.GObject.Structs.TypeClass
     typeClassPeekStatic                     ,
 
 
--- ** ref #method:ref#
-
-    typeClassRef                            ,
-
-
 -- ** unref #method:unref#
 
 #if defined(ENABLE_OVERLOADING)
@@ -150,7 +145,7 @@ instance CallocPtr TypeClass where
     boxedPtrCalloc = callocBytes 8
 
 
--- | Construct a `TypeClass` struct initialized to zero.
+-- | Construct a t'TypeClass' struct initialized to zero.
 newZeroTypeClass :: MonadIO m => m TypeClass
 newZeroTypeClass = liftIO $ boxedPtrCalloc >>= wrapPtr TypeClass
 
@@ -306,7 +301,7 @@ instance (signature ~ (FCT.CSize -> m ()), MonadIO m) => O.OverloadedMethod Type
 instance O.OverloadedMethodInfo TypeClassAddPrivateMethodInfo TypeClass where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeClass.typeClassAddPrivate",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeClass.html#v:typeClassAddPrivate"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeClass.html#v:typeClassAddPrivate"
         })
 
 
@@ -375,7 +370,7 @@ instance (signature ~ (GType -> m (Ptr ())), MonadIO m) => O.OverloadedMethod Ty
 instance O.OverloadedMethodInfo TypeClassGetPrivateMethodInfo TypeClass where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeClass.typeClassGetPrivate",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeClass.html#v:typeClassGetPrivate"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeClass.html#v:typeClassGetPrivate"
         })
 
 
@@ -448,7 +443,7 @@ instance (signature ~ (m TypeClass), MonadIO m) => O.OverloadedMethod TypeClassP
 instance O.OverloadedMethodInfo TypeClassPeekParentMethodInfo TypeClass where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeClass.typeClassPeekParent",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeClass.html#v:typeClassPeekParent"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeClass.html#v:typeClassPeekParent"
         })
 
 
@@ -472,7 +467,7 @@ instance O.OverloadedMethodInfo TypeClassPeekParentMethodInfo TypeClass where
 --           , argDestroy = -1
 --           , argCallerAllocates = False
 --           , argCallbackUserData = False
---           , transfer = TransferNothing
+--           , transfer = TransferEverything
 --           }
 --       ]
 -- Lengths: []
@@ -509,7 +504,7 @@ instance (signature ~ (m ()), MonadIO m) => O.OverloadedMethod TypeClassUnrefMet
 instance O.OverloadedMethodInfo TypeClassUnrefMethodInfo TypeClass where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeClass.typeClassUnref",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeClass.html#v:typeClassUnref"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeClass.html#v:typeClassUnref"
         })
 
 
@@ -734,58 +729,6 @@ typeClassPeekStatic type_ = liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 #endif
 
--- method TypeClass::ref
--- method type : MemberFunction
--- Args: [ Arg
---           { argCName = "type"
---           , argType = TBasicType TGType
---           , direction = DirectionIn
---           , mayBeNull = False
---           , argDoc =
---               Documentation
---                 { rawDocText = Just "type ID of a classed type"
---                 , sinceVersion = Nothing
---                 }
---           , argScope = ScopeTypeInvalid
---           , argClosure = -1
---           , argDestroy = -1
---           , argCallerAllocates = False
---           , argCallbackUserData = False
---           , transfer = TransferNothing
---           }
---       ]
--- Lengths: []
--- returnType: Just
---               (TInterface Name { namespace = "GObject" , name = "TypeClass" })
--- throws : False
--- Skip return : False
-
-foreign import ccall "g_type_class_ref" g_type_class_ref :: 
-    CGType ->                               -- type : TBasicType TGType
-    IO (Ptr TypeClass)
-
-{-# DEPRECATED typeClassRef ["(Since version 2.84)","Use 'GI.GObject.Functions.typeClassGet' instead"] #-}
--- | Increments the reference count of the class structure belonging to
--- /@type@/.
--- 
--- This function will demand-create the class if it doesn\'t exist already.
-typeClassRef ::
-    (B.CallStack.HasCallStack, MonadIO m) =>
-    GType
-    -- ^ /@type@/: type ID of a classed type
-    -> m TypeClass
-    -- ^ __Returns:__ the t'GI.GObject.Structs.TypeClass.TypeClass'
-    --   structure for the given type ID
-typeClassRef type_ = liftIO $ do
-    let type_' = gtypeToCGType type_
-    result <- g_type_class_ref type_'
-    checkUnexpectedReturnNULL "typeClassRef" result
-    result' <- (newPtr TypeClass) result
-    return result'
-
-#if defined(ENABLE_OVERLOADING)
-#endif
-
 #if defined(ENABLE_OVERLOADING)
 type family ResolveTypeClassMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
     ResolveTypeClassMethod "addPrivate" o = TypeClassAddPrivateMethodInfo
